@@ -98,8 +98,8 @@ cluster.im.glm<-function(mod, dat, cluster, ci.level = 0.95, report = TRUE, drop
   dat <- dat[used.idx,]                                                 # keep only active observations
   clust <- as.vector(unlist(dat[[clust.name]]))                         # store cluster index in convenient vector
   G<-length(unique(clust))                                              # how many clusters are in this model?
-  ind.variables <- names(coefficients(mod))                             # what independent variables are in this model?
-  
+  ind.variables.full <- names(coefficients(mod))                        # what independent variables are in this model?
+  ind.variables <- rownames(summary(mod)$coefficients)                  # what non-dropped independent variables in this model?
   
   b.clust <- matrix(data = NA, nrow = G, ncol = length(ind.variables))  # a matrix to store the betas
   n.clust <- c() 
@@ -122,11 +122,22 @@ cluster.im.glm<-function(mod, dat, cluster, ci.level = 0.95, report = TRUE, drop
     # should we stop if one cluster-specific model does not converge?
     if(drop==FALSE){
       if(fail == T){stop("cluster-specific model returned error (try drop = TRUE)", call.=FALSE)}
-      b.clust[i,] <- coefficients(clust.mod)                                    # store the cluster i beta coefficient
+      
+      # detect whether variables were dropped in individual clusters
+      if(length(rownames(summary(clust.mod)$coefficients)) != length(ind.variables)){
+        stop("cluster-specific model(s) dropped variables; ensure that all variables vary within clusters", call.=FALSE)
+      }
+      
+      b.clust[i,] <- coefficients(clust.mod)[ind.variables]                                    # store the cluster i beta coefficient
       
     }else{
       if(fail == F){
-        b.clust[i,] <- coefficients(clust.mod)                                  # store the cluster i beta coefficient
+        # detect whether variables were dropped in individual clusters
+        if(length(rownames(summary(clust.mod)$coefficients)) != length(ind.variables)){
+          stop("cluster-specific model(s) dropped variables; ensure that all variables vary within clusters", call.=FALSE)
+        }
+        
+        b.clust[i,] <- coefficients(clust.mod)[ind.variables]                                  # store the cluster i beta coefficient
       }else{
         b.clust[i,] <- NA
       }
@@ -217,6 +228,13 @@ cluster.im.glm<-function(mod, dat, cluster, ci.level = 0.95, report = TRUE, drop
       cat("\n", "Note:", G.o - G, "clusters were dropped (see help file).", "\n", "\n")
     }
     
+    if(length(ind.variables) < length(ind.variables.full)){
+      cat("\n", "\n", "****", "Note: ", length(ind.variables.full) - length(ind.variables), " variables were unidentified in the model and are not reported.", "****", "\n", sep="")
+      cat("Variables not reported:", "\n", sep="")
+      cat(ind.variables.full[!ind.variables.full %in% ind.variables], sep=", ")
+      cat("\n", "\n")
+    }
+    
   }
  
   
